==> web-audio-engine-0.10.2.tgz: package/lib/api/PannerNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioNode = require("./AudioNode");

var PannerNode = function (_AudioNode) {
  _inherits(PannerNode, _AudioNode);

  function PannerNode(context) {
    _classCallCheck(this, PannerNode);

    var _this = _possibleConstructorReturn(this, (PannerNode.__proto__ || Object.getPrototypeOf(PannerNode)).call(this, context));

    _this._impl = new impl.PannerNode(context._impl);
    return _this;
  }

  _createClass(PannerNode, [{
    key: "setPosition",
    value: function setPosition(x, y, z) {
      this._impl.setPosition(x, y, z);
    }
  }, {
    key: "setOrientation",
    value: function setOrientation(x, y, z) {
      this._impl.setOrientation(x, y, z);
    }
  }, {
    key: "setVelocity",
    value: function setVelocity(x, y, z) {
      this._impl.setVelocity(x, y, z);
    }
  }, {
    key: "panningModel",
    get: function get() {
      return this._impl.getPanningModel();
    },
    set: function set(value) {
      this._impl.setPanningModel(value);
    }
  }, {
    key: "distanceModel",
    get: function get() {
      return this._impl.getDistanceModel();
    },
    set: function set(value) {
      this._impl.setDistanceModel(value);
    }
  }, {
    key: "refDistance",
    get: function get() {
      return this._impl.getRefDistance();
    },
    set: function set(value) {
      this._impl.setRefDistance(value);
    }
  }, {
    key: "maxDistance",
    get: function get() {
      return this._impl.getMaxDistance();
    },
    set: function set(value) {
      this._impl.setMaxDistance(value);
    }
  }, {
    key: "rolloffFactor",
    get: function get() {
      return this._impl.getRolloffFactor();
    },
    set: function set(value) {
      this._impl.setRolloffFactor(value);
    }
  }, {
    key: "coneInnerAngle",
    get: function get() {
      return this._impl.getConeInnerAngle();
    },
    set: function set(value) {
      this._impl.setConeInnerAngle(value);
    }
  }, {
    key: "coneOuterAngle",
    get: function get() {
      return this._impl.getConeOuterAngle();
    },
    set: function set(value) {
      this._impl.setConeOuterAngle(value);
    }
  }, {
    key: "coneOuterGain",
    get: function get() {
      return this._impl.getConeOuterGain();
    },
    set: function set(value) {
      this._impl.setConeOuterGain(value);
    }
  }]);

  return PannerNode;
}(AudioNode);

module.exports = PannerNode;

==> web-audio-engine-0.13.1.tgz: package/lib/api/PannerNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioNode = require("./AudioNode");

var PannerNode = function (_AudioNode) {
  _inherits(PannerNode, _AudioNode);

  function PannerNode(context, opts) {
    _classCallCheck(this, PannerNode);

    var _this = _possibleConstructorReturn(this, (PannerNode.__proto__ || Object.getPrototypeOf(PannerNode)).call(this, context));

    _this._impl = new impl.PannerNode(context._impl, opts);
    return _this;
  }

  _createClass(PannerNode, [{
    key: "setPosition",
    value: function setPosition(x, y, z) {
      this._impl.setPosition(x, y, z);
    }
  }, {
    key: "setOrientation",
    value: function setOrientation(x, y, z) {
      this._impl.setOrientation(x, y, z);
    }
  }, {
    key: "setVelocity",
    value: function setVelocity(x, y, z) {
      this._impl.setVelocity(x, y, z);
    }
  }, {
    key: "panningModel",
    get: function get() {
      return this._impl.getPanningModel();
    },
    set: function set(value) {
      this._impl.setPanningModel(value);
    }
  }, {
    key: "distanceModel",
    get: function get() {
      return this._impl.getDistanceModel();
    },
    set: function set(value) {
      this._impl.setDistanceModel(value);
    }
  }, {
    key: "refDistance",
    get: function get() {
      return this._impl.getRefDistance();
    },
    set: function set(value) {
      this._impl.setRefDistance(value);
    }
  }, {
    key: "maxDistance",
    get: function get() {
      return this._impl.getMaxDistance();
    },
    set: function set(value) {
      this._impl.setMaxDistance(value);
    }
  }, {
    key: "rolloffFactor",
    get: function get() {
      return this._impl.getRolloffFactor();
    },
    set: function set(value) {
      this._impl.setRolloffFactor(value);
    }
  }, {
    key: "coneInnerAngle",
    get: function get() {
      return this._impl.getConeInnerAngle();
    },
    set: function set(value) {
      this._impl.setConeInnerAngle(value);
    }
  }, {
    key: "coneOuterAngle",
    get: function get() {
      return this._impl.getConeOuterAngle();
    },
    set: function set(value) {
      this._impl.setConeOuterAngle(value);
    }
  }, {
    key: "coneOuterGain",
    get: function get() {
      return this._impl.getConeOuterGain();
    },
    set: function set(value) {
      this._impl.setConeOuterGain(value);
    }
  }]);

  return PannerNode;
}(AudioNode);

module.exports = PannerNode;
